@@ -1,10 +1,10 @@
-from settings import db_location
-from pysqlite2 import dbapi2 as sqlite3
+from .settings import db_location
+import sqlite3
 import time
 from math import degrees, sin, asin, cos, radians
 
 '''
-© This data includes information copied with permission from Canada Post Corporation.
+(c) This data includes information copied with permission from Canada Post Corporation.
 '''
 
 class ConnectionManager(object):
@@ -17,7 +17,7 @@ class ConnectionManager(object):
         conn = sqlite3.connect(db_location)
         conn.close()
             
-    def query(self, sql):
+    def query(self, sql, args=()):
         conn = None
         retry_count = 0
         while not conn and retry_count <= 10:
@@ -25,7 +25,7 @@ class ConnectionManager(object):
         # then just give up...
             try:
                 conn = sqlite3.connect(db_location)
-            except sqlite3.OperationalError, x:
+            except sqlite3.OperationalError:
                 retry_count += 1
                 time.sleep(0.001)
         
@@ -33,14 +33,14 @@ class ConnectionManager(object):
             raise sqlite3.OperationalError("Can't connect to sqlite database.")
                 
         cursor = conn.cursor()
-        cursor.execute(sql)
+        cursor.execute(sql, args)
         res = cursor.fetchall()
         conn.close()
         return res
 
-PC_QUERY = "SELECT * FROM PostalCodes WHERE fsa='%s'"
-PC_RANGE_QUERY = "SELECT * FROM PostalCodes WHERE longitude >= %s and longitude <= %s AND latitude >= %s and latitude <= %s"
-PC_FIND_QUERY = "SELECT * FROM PostalCodes WHERE city LIKE '%s' AND province LIKE '%s'"
+PC_QUERY = "SELECT * FROM PostalCodes WHERE fsa=?"
+PC_RANGE_QUERY = "SELECT * FROM PostalCodes WHERE longitude >= ? and longitude <= ? AND latitude >= ? and latitude <= ?"
+PC_FIND_QUERY = "SELECT * FROM PostalCodes WHERE city LIKE ? AND province LIKE ?"
 
 class PostalCode(object):
     def __init__(self, data):
@@ -52,6 +52,12 @@ class PostalCode(object):
         self.timezone = data[5]
         self.dst = data[6]
 
+    def __repr__(self):
+        attrs = ["postalcode", "city", "province", "longitude", "latitude", "timezone", "dst"]
+        attrs = ', '.join(f'{a}={repr(getattr(self, a))}' for a in attrs)
+        return f"{self.__class__.__name__}({attrs})"
+
+
 def format_result(postalcodes):
     if len(postalcodes) > 0:
         return [PostalCode(code) for code in postalcodes]
@@ -93,7 +99,7 @@ class PostalCodeDatabase(object):
         
         long_range  = (pc.longitude - lat_delta, pc.longitude + lon_delta)    
         
-        return format_result(self.conn_manager.query(PC_RANGE_QUERY % (
+        return format_result(self.conn_manager.query(PC_RANGE_QUERY , (
             long_range[0], long_range[1],
             lat_range[0], lat_range[1]
         )))
@@ -109,10 +115,10 @@ class PostalCodeDatabase(object):
         else:
             province = province.upper()
             
-        return format_result(self.conn_manager.query(PC_FIND_QUERY % (city, province)))
+        return format_result(self.conn_manager.query(PC_FIND_QUERY , (city, province)))
         
     def get(self, pc):
-        return format_result(self.conn_manager.query(PC_QUERY % pc))
+        return format_result(self.conn_manager.query(PC_QUERY , (pc,)))
             
     def __getitem__(self, pc):
         pc = self.get(str(pc))
